#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-6nMQL6SNgCh7cSOIK1yPEM
key:                  text-latin1-0.3.1-6nMQL6SNgCh7cSOIK1yPEM
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  aa1e021111e1dc83f9f815ac03914636
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-6nMQL6SNgCh7cSOIK1yPEM
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    data-checked-0.3-5oT0Wocuz7gRbXJUwq9cc
    hashable-1.4.7.0-AuDVFqXH7XaG9xiVOVTNBi text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

